This is a highly subjective question, but if you are new to web development, you will be asking these kinds of questions. Given that you're considering python, logically it makes sense to pick a python-based web framework. If you're going to do AJAX, you should really use JSONRPC. If you're using JSONRPC, you should pick a framework that is known to have mature JSONRPC server-side support, and that means Django, Web2Py, Flask, and many more. See the Pyjamas Wiki for links to various JSONRPC integration HOWTOs.

That having been said: if you're starting entirely from scratch, Django has to come out overall on top, even though you will not be using all of its features. The SQL ORM in Django is excellent; the tutorials to get started are excellent; the developers and users on the (busy) IRC channel are very helpful and responsive.